bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 7. Aventiure
___________________________________________________ #### <Wie Gvnther Prvnhilde gewan>
| ### n der selben zite do was ir schif gegan ### der bvrch also nahen do sach der kvnich stan ### oben in den venstren manich schoene meit ### daz er si niht erkande daz was im werlich leit ### Er fragte Sifriden den gesellen sin ### ist iv iht daz kvnde ob disiv <magedin> ### die dort nider schowent gen vns vf die fluot ### swie ir herre heize si sint vil hohe gemvot
###### 379 | ### Do sprach der herre Sifrit nu sult ir tovgen spehen ### vnder den iunchfrowen vnde sult mir danne iehen ### welhe ir nemen woldet hetet irs gewalt ### daz tuon ich sprach Gunther ein riter kuene vnde balt
###### 380 | ### Ich sihe ir eine in einem venster stan ### in snewizer wete div ist so wol getan ### die wellent miniv ovgen durch ir schoenen lip ### ob ich gewalt des hete si muese werden min wip
###### 381 | ### Dir hat erwelt vil rehte diner ovgen schin ### ist ist div edel Prunhilt daz schone magedin ### nach der din herze ringet din sin vnd ovch din mvot ### alle ir geberde dunket Gvnther guot
###### 382 | ### Do hiez div kvniginne vz den venstren stan ### ir herliche meide si solden da niht stan ### den fremden an ze <sehenne> des waren si bereit ### waz do die fruewen taten daz ist vns sider geseit
###### 383 | ### Gen den vnkvnden strichen si ir lip ### des ie site heten watlichiv wip ### an div engen venster komen si gegan ### da si die helde sahen daz was dvrh schowen getan
###### 384 | ### Rehte in einer maze den helden vil gemeit ### von sneblanker varwe ir ros vnd ovch ir cleit ### waren vil geliche ir schilde wol getan ### die lvhte von den handen den wetlichen man
###### 385 | ### Ir satel wol gesteinet ir furbuoge smal ### si riten herliche fur Prunhilde sal ### daran hiengen schellen von lihtem golde rot ### si chomen zvo dem lande als ez ir ellen in gebot
###### 386 | ### Mit im kom <do> Danchwart vnd ovch Hagne [16b] ### wier horen sagen wie die degne ### von rabenswarzer varwe truogen richiv kleit ### ir schilde waren niwe michel guot vnde breit
###### 387 | ### Von India dem lande sach man si steine tragen ### do kos man an ir wæte vil herlichen wagen ### si liezen an huote daz schifel di der fluot ### sus riten zuo der burge die helde kuene vnde guot
###### 388 | ### Sehs vnd ahzech turne si sahen drinne stan ### dri palas wite vnd einen sal wol getan ### von edelem marmelsteine gruone alsam ein gras ### darinne selbe Prvnhilt mit ir ingesinde was
###### 389 | ### Div burch was entslozen vil wite vf getan ### do liefen in enkegen die Prvnhilde man ### vnd enphiengen die geste in ir frovwen lant ### ir ros hiez man behalden vnd ir schilde vor der hant
###### 390 | ### Do sprach ein kamerere gebet vns div swert ### vnd die liehten brvnne des sit ir vngewert ### sprach von Troien Hagne wir wellens selbe tragen ### do begvnde Sifrit den hovesite sagen
###### 391 | ### In dirre burch phliget man daz wil ich iv sagen ### daz neheine geste svlen wafen tragen ### lat si tragen hinnen daz ist wol getan ### der volgte vngerne Hagne Gvnthers man
###### 392 | ### Man hiez den gesten senken vnd schafen gvot gemach ### manigen snellen rechen man ze hove sach ### in furstlicher wete allenthalben gan ### doch wart michel schovwen an die kuenen getan
###### 393 | ### Ir svlt mich lazen hoeren sprach diu kvnigin ### wer die vnkvnden reken mvgen sin ### die dortsihe so herliken stan ### vnd durch wes liebe die helde her gevarn han
###### 394 | ### Do sprach ein ir gesinde frovwe ich mach wol iehen ### daz ich ir deheinen mer habe gesehen ### wan Sifride geliche einer darunder <stat> ### den svlt ir wol enpfahen daz ist frovwe min rat
###### 395 | ### Do sprach div kvniginne nv brinch mir min gewant ### vnd ist der starke Sifrit komen in min lant ### durch willen miner minne ez gat im an den lip ### ich furhte in niht so sere daz ich werde sin wip
###### 396 | ### Prunhilt div schone wart schiere wol gekleit ### do gie mit ir dannen manigiv schoniv meit ### wol hvndert oder mere gezieret was ir lip ### die gesten wolden schovwen div wetlichen wip
###### 397 | ### Da mite giengen degne vz Islant ### Prvnhilde reken die truogen swert enhant ### funfhvndert oder mere daz was den gesten leit ### do stuonden von dem sedele die kuenen helde gemeit
###### 398 | ### Do div kvneginne Sifriden sach ### zuo dem gaste <si> zvhtechlichen sprach ### sit willekomen her Sifrit her in dizze lant [17a] ### waz meint iwer reise daz het ich gerne bechant
###### 399 | ### Vil michel <genade> frov Prvnhilt ### daz ir mich ruochet gruozen fursten tohter milt ### vor disem edeln reken der hie vor mir stat ### wan der ist min herre der ern het ich gerne rat
###### 400 | ### Er ist kvnich ze Rine was sol ich sagen mer ### durch dine liebe sin wir gevarn her ### er wil dich gerne minnen swaz im da von geschiht ### bedenke dichs becite er lat dich sin niht
###### 401 | ### Er ist geheizen Gunther ein kvnich rich vnd her ### erwurb er dine minne schone gert er nih mer ### durch dich mit im ich her gevarn han ### werer niht min herre ich hetez nimmer getan
###### 402 | ### Si sprach er ist din herre vnd du sin man ### wil er min geteiltiv spil also bestan ### behabe er die meisterschaft so wird ich sin wip ### gewinne aber ich ez get iv allen an den lip
###### 403 | ### Do sprach von Trony Hagne frove lat vns sehen ### iwer spil geteiltiv end iv mvoste iehen ### Gvnther min herre da mvoz ez herte sin ### er trowet wol erwerben ein alse schvone kvnigin
###### 404 | ### Den stein sol er werfen vnd springen darnach ### den ger mit mir schiezen lat iv sin niht ze gach ### ir mvget hie wol verliesen die ere vnd ovch den lip ### des svlt ir ivch bedenken sprach daz minnechliche wip
###### 405 | ### Sifrit der snelle zvo deme kvnige trat ### allen sinen willen er in reden bat ### gen der kvniginne er sold an angest sin ### ich sol dich wol behueten vor ir mit den listen min
###### 406 | ### Do sprach der kvnich Gvnther kvneginne her ### nv teilt swaz ir gebietet vnd werez dannoch mer ### ich bestvend ez allez dvrch iwren schoenen lip ### min hovbet ich verlivse ir enwerdet min wip
###### 407 | ### Do div kvniginne sin rede vernam ### der spile bat si gahen als ir daz gezamn ### si hiez ir ze strite bringen ir gewant ### ein brunne von golde vnd einen gvoten schildes rant
###### 408 | ### Ein wafenhemde sidin leite an div meit ### daz in deheime strite wafen nie versneit ### von pfelle vz der Libya ez was wol getan ### von porten lieht gewurhte schein liehte daran
###### 409 | ### Die zit wart den reken in gelfpe vil gedruot ### Danchwart vnd Hagne waren vngefruot ### wi ez dem kvnige ergienge des sorgte in der mvot ### si dahten vnser reise ist vns gesten niht ze gvot
###### 410 | ### Die wile was ovch Sifrit der wetliche man ### end ez ienman wesse zuo dem schife gegan ### da er sin tarnkappe verborgen vant ### darin slovf er schiere do was er niemen bechant
###### 411 | ### Er ilte hin widere do sach er reken vil [17b] ### da div kvniginne teilte ir hohiv spil ### da gie er tovgenlichen daz in da niemen sach ### aller di da waren von listen daz geschach
###### 412 | ### Der rinch was beceiget da soldez spil geschehen ### vor manigen kvenen reken die daz solden sehen ### wol siben hvndert sach man wafen tragen ### swem da gelvnge daz si die warheit solden sagen
###### 413 | ### Do was ovch chomen Prunhilt gewafent man die vant ### sam ob si wolde striten vm elliv kvniges lant ### ia truoch si ob den siden manigen goldes zein ### darunder minnechlichen ir liehtiv varwe schein
###### 414 | ### Do kom ir gesinde vnd truogen dar zehant ### von alrotem golde einen schildesrant ### mit stalherten spangen michel vn– breit ### darvnder spilen wolde div uil minnechliche meit
###### 415 | ### Der meide schildevezel ein edel borte was ### darvof lagen steine gruene alsam ein gras ### der luhte manigerleye mitschine widerz golt ### er mvoste wesen kuene dem div frovwe wurde holt
###### 416 | ### Der schilt was vnder bukeln als vns daz ist geseit ### drier spannen diche den tragen solde div meit ### von stale vnd ovch von golde rich er was genuoch ### den ir kamerere vierde selbe kvme getruoch
###### 417 | ### Also der degen Hagne den schilt dar tragen sach ### mit grimmen mvote der helt von Trony sprach ### wa nv kvnich Gunther wi verliesen wir den lip ### der ir da gert div ist des tivvels wip
###### 418 | ### Do truoch man der frovwen swære vnde groz ### einen vil scharfen ger den si ze allen ziten schoz ### starch vnd vngefuege michel vnde breit ### der ze sinen eken vil freislichen sneit
###### 419 | ### Von des gers swere hoeret wunder sagen ### vierdehap messe was dazvo geslagen ### den truogen kuone dri Prunhilde man ### Gvnther der edele darvmbe sorge gewan
###### 420 | ### Do sprach Hagnen bruoder der kuene Danchwart ### mich riwet innerchlichen disiv hovevart ### nv hiezen wir ie reken wie fliesen wir den lip ### svln vns in disem lande nv verderben div wip
###### 421 | ### Mich muet harte sere daz ich kom in daz lant ### hete min bruoder Hagene sin wafen an der hant ### vnd ovch ich daz mine so mohten samfte gan ### mit ir ubermuete alle Prunhilde man
###### 422 | ### Vvir solden vngevangen wol rumen dice lant ### sprach sin bruoder Hagene het wir daz gewant ### des wir ze not bedurfen vnd div swert vil guot ### so wurde wol gesenftet der schoenen frovwen vbermuot
###### 423 | ### Wol horte div maget edele waz der degen sprach ### mit smielindem mvnde si vber ahsel sach ### nv er dvnket sich so chuone so traget in ir gewant [18a] ### ir vil scharfen wafen gebet den helden an die hant
###### 424 | ### Do si div swert gewunnen so div meit gebot ### der vil kuone Danchwart von freuden wart rot ### nv spilen swez si wellen sprach der kuene man ### Gvnther ist vnbetvngen sit wir vnser wafen han
###### 425 | ### Brvnhilde sterke grozlichen schein ### man truoch ir zuo dem ringe einen swern stein ### groz vnd vngefuoge michel vnde wel ### in truogen kuene zwelfe der kuenen helde vn– snel
###### 426 | ### Den warf si ze allen ziten so si den ger verschoz ### der Burgonden sorge was vil harte groz ### wafen sprach Hagne waz hat der kunich ze trvvt ### ia sol si in der helle sin des vbelen tivvels bruot
###### 427 | ### An ir vil wize arme si die ermel want ### si begvnde vazzen den schilt an der hant ### den ger si hohe zvchte do gie ez an den strit ### die ellenden geste vorhten Prunhilde nit
###### 428 | ### Vnd were im Sifrit niht da ze helfe komen ### so hete si Gvnthere sinen lip benomen ### er gie dar tovgenliche vnd ruort im sine hant ### Gvnther sine liste harte sorchlich ervant
###### 429 | ### Er sprach gip mir von handen den schilt la mich tragen ### vnd merke rehte waz dv mich hoerest sagen ### nv habe dv die gebærde div werch wil ich began ### do er in bekande ez was im liebe getan
###### 430 | ### Do schoz vil kreftichlichen div herliche meit ### vf einen schilt niwen michel unde breit ### den truoch an siner hende daz Siglinde kint ### daz fivr spranch von stale sam ez wate der wint
###### 431 | ### Des starken gers snide al durch den schilt gebrach ### daz man daz fiuuer lovgen vz den ringen sach ### des svzzes beide struochten die kreftige man ### wan div trankappe si weren tot da bestan
###### 432 | ### Sifride dem kuene von mvnde brast daz bluot ### vil balde spranch er widere do nam der helt guot ### den ger den si geschozen im hete durch den rant ### den schoz do hin wider des starken Sifrides hant
###### 433 | ### Daz fiwer stovp vz ringen als ob ez tribe der wint ### den ger schoz mit ellen daz Sigmvndes kint ### si mohte mit ir krefte des schuzes niht gestan ### ez en hete nimmer der kunich Gunther getan
###### 434 | ### Brunhilt div schoene balde vf spranch ### edel riter Gvnther des schuzzes habe danch ### si wande daz erz hete mit siner kraft getan ### nein si hete gevellet ein verre kreftiger man
###### 435 | ### Do gie si hin balde zornich was ir muot ### den stein huop vil hohe div edel maget guot ### si swanch in kreftechliche verre von der hant ### do spranch si nach dem wurfe daz luote erklang ir gewant
###### 436 | ### Der stein was gevallen zwelf klafter dan [18b] ### den wrf brach mit sprvngen diu maget wolgetan ### dar gie der snelle Sifrit da der stein gelach ### Gvnther in wegete der helt des wurfes pflach
###### 437 | ### Sifrit was kuene kreftich vnde lanch ### den stein warf er verrer dar zuo er witer spranch ### von sinen schoenen listen het er kraft genvoch ### daz er mit den sprvnge den kvnich Gvnther truoch
###### 438 | ### Zvo ir ingesinde ein teil si lûte sprach ### do si ze ende des ringes den helt gesunden sach ### balde komet her naher mage vnde mine man ### ir svlt kvnich Gvnther alle werden vndertan
###### 439 | ### Do leiten die vil kuonen div wafen von der hant ### si buten sich ze fuozen von Burgonden lant ### Gvnther dem richen vil manich kuoner man ### si wanden er hete mit siner kraft div spil getan
###### 440 | ### Er gruoztes minechliche ia was er tvgenden rich ### do man im bi der hende div maget lobelich ### si erlobte im daz er solde haben da gewalt ### des fruoten sich die degne vil kuene vnde balt
###### 441 | ### Si bat den riter edele mit ir dannen gan ### in den palas witen also daz wart getan ### do erbot manz den reken mit dienste dester baz ### Danchwart vnd Hagne muosen lazen ane haz
###### 442 | ### Sifrit der snelle wise er was genuoch ### sin tarnkappe er ze behalten truoch ### do gie er hin wider da manich frovwe saz ### da er vnd ander degne alles leides vergaz
###### 443 | ### So wol mich dirre mere sprach Sifrit der degen ### daz iwer hohverten also ist gelegen ### daz iemen lebet der iwer meister mvge sin ### nv svlt ir maget edel uns hinnen volgen an den Rin
###### 444 | ### Do sprach div wolgetane des mak niht ergan ### ez muozen ê bevinden maget vnde mine man ### ia mag ich also lihte gerumen niht min lant ### die minen beste frivnde mvezen werden ê bestan
###### 445 | ### Do hiez si boten riten allenthalben dan ### si besande ir frivnde mage vnde man ### die bat si ze Isensteine komen vnerwant ### vnd hiez in geben allen rich unde herlich gewant
###### 446 | ### Si riten tegeliche spate vnde frvo ### Prunhilde burge scharhafte zuo ### iaria sprach Hagene waz haben wir getan ### wir erbeiten hie vbele der schoene Brunhilde man
###### 447 | ### So si nu mit ir krefte koment in daz lant ### der kvniginne wille ist vns vnbekant ### waz ob si also zvrnet daz wir sin verlorn ### so ist div maget edel vns ze grozen sorgen geborn
###### 448 | ### Do sprach der starke Sifrit daz sol ich vndersten ### des ir da habet sorge des laze ich niht ergen ### ich sol in helfe bringen her in dizze lant [19a] ### von vzerwelten reken die iu noch nie wurden bechant
###### 449 | ### Ir svlt nach mir niht vragen ich wil hinnen varn ### got muese iwer ere die zit wol bewarn ### ich kuome schiere widere vnd bringiv tusent man ### der aller besten degne der ich kvnde ie gewan
###### 450 | ### So sit et niht ze lange sprach der kvnich do ### wir sin iwer helfe billichen vro ### sprach ich kvme widere in vil kvrzen tagen ### ir mich habet gesendet sult ir der kuniginne sagen

<<< Übersicht <<< vorige Seite nächste Seite >>>